Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(44)

Unified Diff: media/renderers/audio_renderer_impl.h

Issue 2517503003: Reland: Make more media APIs aware of |delay| and |delay_timestamp| (Closed)
Patch Set: Comments from chcunningham@ and Dale Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/blink/webaudiosourceprovider_impl_unittest.cc ('k') | media/renderers/audio_renderer_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/renderers/audio_renderer_impl.h
diff --git a/media/renderers/audio_renderer_impl.h b/media/renderers/audio_renderer_impl.h
index b1622cc380deab5be5635f24ece49ef95c1258d3..71676ba9a6a51a525b87087b54a77df55fc86a96 100644
--- a/media/renderers/audio_renderer_impl.h
+++ b/media/renderers/audio_renderer_impl.h
@@ -152,11 +152,12 @@ class MEDIA_EXPORT AudioRendererImpl
// Render() updates the pipeline's playback timestamp. If Render() is
// not called at the same rate as audio samples are played, then the reported
// timestamp in the pipeline will be ahead of the actual audio playback. In
// this case |frames_delayed| should be used to indicate when in the future
// should the filled buffer be played.
- int Render(AudioBus* audio_bus,
- uint32_t frames_delayed,
- uint32_t frames_skipped) override;
+ int Render(base::TimeDelta delay,
+ base::TimeTicks delay_timestamp,
+ int prior_frames_skipped,
+ AudioBus* dest) override;
void OnRenderError() override;
// Helper methods that schedule an asynchronous read from the decoder as long
« no previous file with comments | « media/blink/webaudiosourceprovider_impl_unittest.cc ('k') | media/renderers/audio_renderer_impl.cc » ('j') | no next file with comments »
@@ -152,11 +152,12 @@ class MEDIA_EXPORT AudioRendererImpl
// not called at the same rate as audio samples are played, then the reported
// timestamp in the pipeline will be ahead of the actual audio playback. In
- // this case |frames_delayed| should be used to indicate when in the future
+ // this case |delay| should be used to indicate when in the future
// should the filled buffer be played.

Powered by Google App Engine
This is Rietveld 408576698